import { localize } from 'vscode/vscode/vs/nls';

const terminalSuggestConfigSection = 'terminal.integrated.suggest';
const terminalSuggestConfiguration = {
    ["terminal.integrated.suggest.enabled" ]: {
        restricted: true,
        markdownDescription: ( localize(
            11369,
            "Enables experimental terminal Intellisense suggestions for supported shells ({0}) when {1} is set to {2}.\n\nIf shell integration is installed manually, {3} needs to be set to {4} before calling the shell integration script.",
            'PowerShell v7+',
            `\`#${"terminal.integrated.shellIntegration.enabled" }#\``,
            '`true`',
            '`VSCODE_SUGGEST`',
            '`1`'
        )),
        type: 'boolean',
        default: false,
    },
    ["terminal.integrated.suggest.quickSuggestions" ]: {
        restricted: true,
        markdownDescription: ( localize(
            11370,
            "Controls whether suggestions should automatically show up while typing. Also be aware of the {0}-setting which controls if suggestions are triggered by special characters.",
            `\`#${"terminal.integrated.suggest.suggestOnTriggerCharacters" }#\``
        )),
        type: 'boolean',
        default: true,
    },
    ["terminal.integrated.suggest.suggestOnTriggerCharacters" ]: {
        restricted: true,
        markdownDescription: ( localize(
            11371,
            "Controls whether suggestions should automatically show up when typing trigger characters."
        )),
        type: 'boolean',
        default: true,
    },
    ["terminal.integrated.suggest.runOnEnter" ]: {
        restricted: true,
        markdownDescription: ( localize(
            11372,
            "Controls whether suggestions should run immediately when `Enter` (not `Tab`) is used to accept the result."
        )),
        enum: ['ignore', 'never', 'exactMatch', 'exactMatchIgnoreExtension', 'always'],
        markdownEnumDescriptions: [
            ( localize(
                11373,
                "Ignore suggestions and send the enter directly to the shell without completing. This is used as the default value so the suggest widget is as unobtrusive as possible."
            )),
            ( localize(11374, "Never run on `Enter`.")),
            ( localize(11375, "Run on `Enter` when the suggestion is typed in its entirety.")),
            ( localize(
                11376,
                "Run on `Enter` when the suggestion is typed in its entirety or when a file is typed without its extension included."
            )),
            ( localize(11377, "Always run on `Enter`."))
        ],
        default: 'ignore',
    },
    ["terminal.integrated.suggest.builtinCompletions" ]: {
        restricted: true,
        markdownDescription: ( localize(
            11378,
            "Controls which built-in completions are activated. This setting can cause conflicts if custom shell completions are configured in the shell profile."
        )),
        type: 'object',
        properties: {
            'pwshCode': {
                description: ( localize(
                    11379,
                    'Custom PowerShell argument completers will be registered for VS Code\'s `code` and `code-insiders` CLIs. This is currently very basic and always suggests flags and subcommands without checking context.'
                )),
                type: 'boolean'
            },
            'pwshGit': {
                description: ( localize(
                    11380,
                    'Custom PowerShell argument completers will be registered for the `git` CLI.'
                )),
                type: 'boolean'
            },
        },
        default: {
            pwshCode: true,
            pwshGit: true,
        }
    },
};

export { terminalSuggestConfigSection, terminalSuggestConfiguration };
