import { localize } from 'vscode/vscode/vs/nls';

const DEFAULT_LOCAL_ECHO_EXCLUDE = ['vim', 'vi', 'nano', 'tmux'];
const terminalTypeAheadConfiguration = {
    ["terminal.integrated.localEchoLatencyThreshold" ]: {
        description: ( localize(
            11783,
            "Length of network delay, in milliseconds, where local edits will be echoed on the terminal without waiting for server acknowledgement. If '0', local echo will always be on, and if '-1' it will be disabled."
        )),
        type: 'integer',
        minimum: -1,
        default: 30,
    },
    ["terminal.integrated.localEchoEnabled" ]: {
        markdownDescription: ( localize(
            11784,
            "When local echo should be enabled. This will override {0}",
            '`#terminal.integrated.localEchoLatencyThreshold#`'
        )),
        type: 'string',
        enum: ['on', 'off', 'auto'],
        enumDescriptions: [
            ( localize(11785, "Always enabled")),
            ( localize(11786, "Always disabled")),
            ( localize(11787, "Enabled only for remote workspaces"))
        ],
        default: 'auto'
    },
    ["terminal.integrated.localEchoExcludePrograms" ]: {
        description: ( localize(
            11788,
            "Local echo will be disabled when any of these program names are found in the terminal title."
        )),
        type: 'array',
        items: {
            type: 'string',
            uniqueItems: true
        },
        default: DEFAULT_LOCAL_ECHO_EXCLUDE,
    },
    ["terminal.integrated.localEchoStyle" ]: {
        description: ( localize(
            11789,
            "Terminal style of locally echoed text; either a font style or an RGB color."
        )),
        default: 'dim',
        anyOf: [
            {
                enum: ['bold', 'dim', 'italic', 'underlined', 'inverted', '#ff0000'],
            },
            {
                type: 'string',
                format: 'color-hex',
            }
        ]
    },
};

export { DEFAULT_LOCAL_ECHO_EXCLUDE, terminalTypeAheadConfiguration };
